@@ -13,7 +13,8 @@ that we have failed to install the boot loader correctly.
 Please contribute this code to the $PRODUCT project. To do so
 please take a look at the scripts in $SHARE_DIR/finalize,
 for an example you can use the script for Fedora (and RHEL/CentOS/SL) in
-$SHARE_DIR/finalize/Fedora/i386/20_install_grub.sh
+$SHARE_DIR/finalize/Linux-i386/21_install_grub.sh or
+$SHARE_DIR/finalize/Linux-i386/22_install_grub2.sh
 
 --------------------  ATTENTION ATTENTION ATTENTION -------------------
 |                                                                     |
