@@ -26,7 +26,6 @@ extract_partitions() {
     declare device=$1
 
     declare sysfs_name=$(get_sysfs_name $device)
-    declare block_size=$(get_block_size $sysfs_name)
 
     ### check if we can find any partitions
     declare -a sysfs_paths=(/sys/block/$sysfs_name/$sysfs_name*)
@@ -62,13 +61,7 @@ extract_partitions() {
         partition_prefix=${partition_name%$partition_nr}
 
         size=$(get_disk_size ${path#/sys/block/})
-        if [[ -r $path/start ]] ; then
-            start_block=$(< $path/start)
-            start=$(( $start_block*$block_size ))
-        else
-            Log "Could not determine start of partition $partition_name."
-            start="unknown"
-        fi
+        start=$(get_partition_start ${path#/sys/block/})
 
         echo "$partition_nr $size $start">> $TMP_DIR/partitions_unsorted
     done
@@ -113,7 +106,9 @@ extract_partitions() {
     fi
 
     ### find partition name for gpt disks.
-    if [[ "$disk_label" = "gpt" ]] ; then
+    # For the SUSE specific gpt_sync_mbr partitioning scheme
+    # see https://github.com/rear/rear/issues/544
+    if [[ "$disk_label" = "gpt" || "$disk_label" == "gpt_sync_mbr" ]] ; then
         if [[ "$FEATURE_PARTED_MACHINEREADABLE" ]] ; then
             while read partition_nr size start junk ; do
                 type=$(grep "^$partition_nr:" $TMP_DIR/parted | cut -d ":" -f "6")
@@ -163,6 +158,8 @@ extract_partitions() {
             for flag in $flaglist ; do
                 if [[ "$flag" = boot || "$flag" = root || "$flag" = swap || "$flag" = hidden || "$flag" = raid || "$flag" = lvm || "$flag" = lba || "$flag" = palo || "$flag" = legacy_boot || "$flag" = bios_grub || "$flag" = prep ]] ; then
                     flags="$flags$flag,"
+                elif [[ "$flag" = "type=06" ]] ; then
+                    flags="${flags}prep,"
                 fi
             done
 
@@ -195,6 +192,8 @@ extract_partitions() {
             for flag in $flaglist ; do
                 if [[ "$flag" = boot || "$flag" = root || "$flag" = swap || "$flag" = hidden || "$flag" = raid || "$flag" = lvm || "$flag" = lba || "$flag" = palo || "$flag" = legacy_boot || "$flag" = bios_grub || "$flag" = prep ]] ; then
                     flags="$flags$flag,"
+                elif [[ "$flag" = "type=06" ]] ; then
+                    flags="${flags}prep,"
                 fi
             done
 
@@ -246,14 +245,18 @@ Log "Saving disk partitions."
     # format: disk <disk> <sectors> <partition label type>
     for disk in /sys/block/* ; do
         blockd=${disk#/sys/block/}
-        if [[ $blockd = hd* || $blockd = sd* || $blockd = cciss* || $blockd = vd* || $blockd = xvd* ]] ; then
+        if [[ $blockd = hd* || $blockd = sd* || $blockd = cciss* || $blockd = vd* || $blockd = xvd* || $blockd = dasd* || $blockd = nvme* ]] ; then
             devname=$(get_device_name $disk)
             devsize=$(get_disk_size ${disk#/sys/block/})
 
             disktype=$(parted -s $devname print | grep -E "Partition Table|Disk label" | cut -d ":" -f "2" | tr -d " ")
 
+            echo "# Disk $devname"
+            echo "# Format: disk <devname> <size(bytes)> <partition label type>"
             echo "disk $devname $devsize $disktype"
 
+            echo "# Partitions on $devname"
+            echo "# Format: part <device> <partition size(bytes)> <partition start(bytes)> <partition type|name> <flags> /dev/<partition>"
             extract_partitions "$devname"
         fi
     done
