@@ -1,15 +1,23 @@
+# This file is part of Relax and Recover, licensed under the GNU General
+# Public License. Refer to the included LICENSE for full text of license.
+
 # We support using cfg2html to collect general system information.
 # For this cfg2html has to be installed and it has not been disabled.
 
 # If USE_CFG2HTML is disabled, skip this script
-if [[ ! "$USE_CFG2HTML" =~ ^[yY1] ]]; then
+if ! is_true "$USE_CFG2HTML" ; then
     return
 fi
 
+#if [[ ! "$USE_CFG2HTML" =~ ^[yY1] ]]; then
+#    return
+#fi
+
 # If SKIP_CFG2HTML is enabled, skip this script (backward compatibility)
-if [[ -z "$USE_CFG2HTML" && -z "$SKIP_CFG2HTML" ]]; then
-    return
-fi
+# we promised to drop SKIP_CFG2HTML from 1.18 on
+#if [[ -z "$USE_CFG2HTML" && -z "$SKIP_CFG2HTML" ]]; then
+#    return
+#fi
 
 # No cfg2html binary, skip this script
 if ! has_binary cfg2html; then
